@@ -1,11 +1,10 @@
 """Decoration Utilities."""
 import time
-from typing import Callable, Any
-
-from .misc_utils import format_time, to_string, get_time_str
+from .misc_utils import format_time, to_string, get_time_str, color_print
+import warnings
 
 
-def timer(logger=None) -> Callable:
+def timer(show_args=True, logger=None):
     """Decorate a function to log how log the function took to execute.
 
     Args:
@@ -24,14 +23,17 @@ def timer(logger=None) -> Callable:
 
     """
 
-    def decorator(fn: Callable) -> Callable:
-        def measure_time(*args: Any, **kwargs: Any) -> Any:
+    def decorator(fn):
+        def measure_time(*args, **kwargs):
 
             start = time.time()
             result = fn(*args, **kwargs)
             elapsed_time = time.time() - start
 
-            args_str = to_string(args, last_comma=True) if len(args) and len(kwargs) else to_string(args)
+            if show_args:
+                args_str = to_string(args, last_comma=True) if len(args) and len(kwargs) else to_string(args)
+            else:
+                args_str = ''
 
             info = 'Called %s(%s%s), elapsed time: %.5f(s).' % (fn.__name__, args_str, to_string(kwargs), elapsed_time)
             if logger is not None:
@@ -44,3 +46,31 @@ def timer(logger=None) -> Callable:
         return measure_time
 
     return decorator
+
+
+def deprecated(info=''):
+    """Decorate a deprecated function.
+
+    Args:
+        info: info to show.
+
+    Example:
+        >>> from misc_utils import deprecated
+        >>>
+        >>> @deprecated('old_func() is deprecated now, use new_func() instead.')
+        >>> def old_func():
+        >>>     pass
+        >>>
+        >>> old_func()
+        >>> # DeprecationWarning: old_func() is deprecated now, use new_func() instead.
+
+    """
+    def decorator(fn):
+        def deprecation_info(*args, **kwargs):
+            warnings.warn(info, DeprecationWarning)
+            color_print('DeprecationWarning: ' + info, 1)
+            result = fn(*args, **kwargs)
+            return result
+
+        return deprecation_info
+    return decorator
